@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -71,7 +71,7 @@ __all__ = ("TransferClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -91,7 +91,7 @@ class Exceptions:
 
 class TransferClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html)
     """
 
@@ -107,7 +107,7 @@ class TransferClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#can_paginate)
         """
 
@@ -119,7 +119,7 @@ class TransferClient(BaseClient):
         ExternalId: str,
         HomeDirectory: str = None,
         HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None
     ) -> CreateAccessResponseTypeDef:
@@ -128,7 +128,7 @@ class TransferClient(BaseClient):
         access to upload and download files over the enabled protocols using Amazon Web
         Services Transfer Family.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.create_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_access)
         """
 
@@ -143,16 +143,16 @@ class TransferClient(BaseClient):
         IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
         IdentityProviderType: IdentityProviderTypeType = None,
         LoggingRole: str = None,
-        Protocols: List[ProtocolType] = None,
+        Protocols: Sequence[ProtocolType] = None,
         SecurityPolicyName: str = None,
-        Tags: List["TagTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None,
         WorkflowDetails: "WorkflowDetailsTypeDef" = None
     ) -> CreateServerResponseTypeDef:
         """
         Instantiates an auto-scaling virtual server based on the selected file transfer
         protocol in Amazon Web Services.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.create_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_server)
         """
 
@@ -164,33 +164,33 @@ class TransferClient(BaseClient):
         UserName: str,
         HomeDirectory: str = None,
         HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         SshPublicKeyBody: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateUserResponseTypeDef:
         """
         Creates a user and associates them with an existing file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_user)
         """
 
     def create_workflow(
         self,
         *,
-        Steps: List["WorkflowStepTypeDef"],
+        Steps: Sequence["WorkflowStepTypeDef"],
         Description: str = None,
-        OnExceptionSteps: List["WorkflowStepTypeDef"] = None,
-        Tags: List["TagTypeDef"] = None
+        OnExceptionSteps: Sequence["WorkflowStepTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateWorkflowResponseTypeDef:
         """
         Allows you to create a workflow with specified steps and step details the
         workflow invokes after file transfer completes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.create_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.create_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_workflow)
         """
 
@@ -199,7 +199,7 @@ class TransferClient(BaseClient):
         Allows you to delete the access specified in the `ServerID` and `ExternalID`
         parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.delete_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.delete_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_access)
         """
 
@@ -207,7 +207,7 @@ class TransferClient(BaseClient):
         """
         Deletes the file transfer protocol-enabled server that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.delete_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_server)
         """
 
@@ -215,7 +215,7 @@ class TransferClient(BaseClient):
         """
         Deletes a user's Secure Shell (SSH) public key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_ssh_public_key)
         """
 
@@ -224,7 +224,7 @@ class TransferClient(BaseClient):
         Deletes the user belonging to a file transfer protocol-enabled server you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_user)
         """
 
@@ -232,7 +232,7 @@ class TransferClient(BaseClient):
         """
         Deletes the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.delete_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.delete_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_workflow)
         """
 
@@ -241,7 +241,7 @@ class TransferClient(BaseClient):
         Describes the access that is assigned to the specific file transfer protocol-
         enabled server, as identified by its `ServerId` property and its `ExternalID` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.describe_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_access)
         """
 
@@ -252,7 +252,7 @@ class TransferClient(BaseClient):
         You can use `DescribeExecution` to check the details of the execution of the
         specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.describe_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.describe_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_execution)
         """
 
@@ -263,7 +263,7 @@ class TransferClient(BaseClient):
         Describes the security policy that is attached to your file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_security_policy)
         """
 
@@ -272,7 +272,7 @@ class TransferClient(BaseClient):
         Describes a file transfer protocol-enabled server that you specify by passing
         the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.describe_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_server)
         """
 
@@ -281,7 +281,7 @@ class TransferClient(BaseClient):
         Describes the user assigned to the specific file transfer protocol-enabled
         server, as identified by its `ServerId` property.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_user)
         """
 
@@ -289,21 +289,21 @@ class TransferClient(BaseClient):
         """
         Describes the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.describe_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.describe_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_workflow)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#generate_presigned_url)
         """
 
@@ -315,7 +315,7 @@ class TransferClient(BaseClient):
         `UserName` value assigned to the specific file transfer protocol-enabled server,
         identified by `ServerId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#import_ssh_public_key)
         """
 
@@ -325,7 +325,7 @@ class TransferClient(BaseClient):
         """
         Lists the details for all the accesses you have on your server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_accesses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_accesses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_accesses)
         """
 
@@ -335,7 +335,7 @@ class TransferClient(BaseClient):
         """
         Lists all executions for the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_executions)
         """
 
@@ -346,7 +346,7 @@ class TransferClient(BaseClient):
         Lists the security policies that are attached to your file transfer protocol-
         enabled servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_security_policies)
         """
 
@@ -357,7 +357,7 @@ class TransferClient(BaseClient):
         Lists the file transfer protocol-enabled servers that are associated with your
         Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_servers)
         """
 
@@ -368,7 +368,7 @@ class TransferClient(BaseClient):
         Lists all of the tags associated with the Amazon Resource Name (ARN) that you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_tags_for_resource)
         """
 
@@ -379,7 +379,7 @@ class TransferClient(BaseClient):
         Lists the users for a file transfer protocol-enabled server that you specify by
         passing the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_users)
         """
 
@@ -389,7 +389,7 @@ class TransferClient(BaseClient):
         """
         Lists all of your workflows.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.list_workflows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.list_workflows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_workflows)
         """
 
@@ -399,7 +399,7 @@ class TransferClient(BaseClient):
         """
         Sends a callback for asynchronous custom steps.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#send_workflow_step_state)
         """
 
@@ -408,7 +408,7 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
         `ONLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.start_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#start_server)
         """
 
@@ -417,16 +417,16 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `ONLINE` to
         `OFFLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.stop_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#stop_server)
         """
 
-    def tag_resource(self, *, Arn: str, Tags: List["TagTypeDef"]) -> None:
+    def tag_resource(self, *, Arn: str, Tags: Sequence["TagTypeDef"]) -> None:
         """
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#tag_resource)
         """
 
@@ -444,16 +444,16 @@ class TransferClient(BaseClient):
         `AWS_DIRECTORY_SERVICE` or `API_Gateway` , tests whether your identity provider
         is set up successfully.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#test_identity_provider)
         """
 
-    def untag_resource(self, *, Arn: str, TagKeys: List[str]) -> None:
+    def untag_resource(self, *, Arn: str, TagKeys: Sequence[str]) -> None:
         """
         Detaches a key-value pair from a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#untag_resource)
         """
 
@@ -464,7 +464,7 @@ class TransferClient(BaseClient):
         ExternalId: str,
         HomeDirectory: str = None,
         HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         Role: str = None
@@ -473,7 +473,7 @@ class TransferClient(BaseClient):
         Allows you to update parameters for the access specified in the `ServerID` and
         `ExternalID` parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.update_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.update_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_access)
         """
 
@@ -488,7 +488,7 @@ class TransferClient(BaseClient):
         HostKey: str = None,
         IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
         LoggingRole: str = None,
-        Protocols: List[ProtocolType] = None,
+        Protocols: Sequence[ProtocolType] = None,
         SecurityPolicyName: str = None,
         WorkflowDetails: "WorkflowDetailsTypeDef" = None
     ) -> UpdateServerResponseTypeDef:
@@ -496,7 +496,7 @@ class TransferClient(BaseClient):
         Updates the file transfer protocol-enabled server's properties after that server
         has been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.update_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_server)
         """
 
@@ -507,7 +507,7 @@ class TransferClient(BaseClient):
         UserName: str,
         HomeDirectory: str = None,
         HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         Role: str = None
@@ -515,12 +515,12 @@ class TransferClient(BaseClient):
         """
         Assigns new properties to a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_user)
         """
 
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/transfer.html#Transfer.Paginator.ListServers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/transfer.html#Transfer.Paginator.ListServers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
         """
